@@ -5,6 +5,7 @@ use std::env;
 use std::fs::File;
 use std::io::prelude::*;
 use std::path::{PathBuf, Path};
+use std::process::Command;
 
 fn main() {
     register_dep("Z");
@@ -17,6 +18,11 @@ fn main() {
         return
     }
 
+    if !Path::new("libssh2/.git").exists() {
+        let _ = Command::new("git").args(&["submodule", "update", "--init"])
+                                   .status();
+    }
+
     let mut cfg = cmake::Config::new("libssh2");
 
     let target = env::var("TARGET").unwrap();
@@ -40,7 +46,13 @@ fn main() {
     }
 
     if let Some(path) = env::var_os("DEP_OPENSSL_INCLUDE") {
-        cfg.define("OPENSSL_INCLUDE_DIR", path);
+        if let Some(path) = env::split_paths(&path).next() {
+            if let Some(path) = path.to_str() {
+                if path.len() > 0 {
+                    cfg.define("OPENSSL_INCLUDE_DIR", path);
+                }
+            }
+        }
     }
 
     let dst = cfg.define("BUILD_SHARED_LIBS", "OFF")
